#line 1 "cscanner.c"

#line 3 "cscanner.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer c__create_buffer
#define yy_delete_buffer c__delete_buffer
#define yy_scan_buffer c__scan_buffer
#define yy_scan_string c__scan_string
#define yy_scan_bytes c__scan_bytes
#define yy_init_buffer c__init_buffer
#define yy_flush_buffer c__flush_buffer
#define yy_load_buffer_state c__load_buffer_state
#define yy_switch_to_buffer c__switch_to_buffer
#define yypush_buffer_state c_push_buffer_state
#define yypop_buffer_state c_pop_buffer_state
#define yyensure_buffer_stack c_ensure_buffer_stack
#define yy_flex_debug c__flex_debug
#define yyin c_in
#define yyleng c_leng
#define yylex c_lex
#define yylineno c_lineno
#define yyout c_out
#define yyrestart c_restart
#define yytext c_text
#define yywrap c_wrap
#define yyalloc c_alloc
#define yyrealloc c_realloc
#define yyfree c_free

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define c__create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer c__create_buffer
#endif

#ifdef yy_delete_buffer
#define c__delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer c__delete_buffer
#endif

#ifdef yy_scan_buffer
#define c__scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer c__scan_buffer
#endif

#ifdef yy_scan_string
#define c__scan_string_ALREADY_DEFINED
#else
#define yy_scan_string c__scan_string
#endif

#ifdef yy_scan_bytes
#define c__scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes c__scan_bytes
#endif

#ifdef yy_init_buffer
#define c__init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer c__init_buffer
#endif

#ifdef yy_flush_buffer
#define c__flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer c__flush_buffer
#endif

#ifdef yy_load_buffer_state
#define c__load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state c__load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define c__switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer c__switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define c_push_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state c_push_buffer_state
#endif

#ifdef yypop_buffer_state
#define c_pop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state c_pop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define c_ensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack c_ensure_buffer_stack
#endif

#ifdef yylex
#define c_lex_ALREADY_DEFINED
#else
#define yylex c_lex
#endif

#ifdef yyrestart
#define c_restart_ALREADY_DEFINED
#else
#define yyrestart c_restart
#endif

#ifdef yylex_init
#define c_lex_init_ALREADY_DEFINED
#else
#define yylex_init c_lex_init
#endif

#ifdef yylex_init_extra
#define c_lex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra c_lex_init_extra
#endif

#ifdef yylex_destroy
#define c_lex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy c_lex_destroy
#endif

#ifdef yyget_debug
#define c_get_debug_ALREADY_DEFINED
#else
#define yyget_debug c_get_debug
#endif

#ifdef yyset_debug
#define c_set_debug_ALREADY_DEFINED
#else
#define yyset_debug c_set_debug
#endif

#ifdef yyget_extra
#define c_get_extra_ALREADY_DEFINED
#else
#define yyget_extra c_get_extra
#endif

#ifdef yyset_extra
#define c_set_extra_ALREADY_DEFINED
#else
#define yyset_extra c_set_extra
#endif

#ifdef yyget_in
#define c_get_in_ALREADY_DEFINED
#else
#define yyget_in c_get_in
#endif

#ifdef yyset_in
#define c_set_in_ALREADY_DEFINED
#else
#define yyset_in c_set_in
#endif

#ifdef yyget_out
#define c_get_out_ALREADY_DEFINED
#else
#define yyget_out c_get_out
#endif

#ifdef yyset_out
#define c_set_out_ALREADY_DEFINED
#else
#define yyset_out c_set_out
#endif

#ifdef yyget_leng
#define c_get_leng_ALREADY_DEFINED
#else
#define yyget_leng c_get_leng
#endif

#ifdef yyget_text
#define c_get_text_ALREADY_DEFINED
#else
#define yyget_text c_get_text
#endif

#ifdef yyget_lineno
#define c_get_lineno_ALREADY_DEFINED
#else
#define yyget_lineno c_get_lineno
#endif

#ifdef yyset_lineno
#define c_set_lineno_ALREADY_DEFINED
#else
#define yyset_lineno c_set_lineno
#endif

#ifdef yywrap
#define c_wrap_ALREADY_DEFINED
#else
#define yywrap c_wrap
#endif

#ifdef yyalloc
#define c_alloc_ALREADY_DEFINED
#else
#define yyalloc c_alloc
#endif

#ifdef yyrealloc
#define c_realloc_ALREADY_DEFINED
#else
#define yyrealloc c_realloc
#endif

#ifdef yyfree
#define c_free_ALREADY_DEFINED
#else
#define yyfree c_free
#endif

#ifdef yytext
#define c_text_ALREADY_DEFINED
#else
#define yytext c_text
#endif

#ifdef yyleng
#define c_leng_ALREADY_DEFINED
#else
#define yyleng c_leng
#endif

#ifdef yyin
#define c_in_ALREADY_DEFINED
#else
#define yyin c_in
#endif

#ifdef yyout
#define c_out_ALREADY_DEFINED
#else
#define yyout c_out
#endif

#ifdef yy_flex_debug
#define c__flex_debug_ALREADY_DEFINED
#else
#define yy_flex_debug c__flex_debug
#endif

#ifdef yylineno
#define c_lineno_ALREADY_DEFINED
#else
#define yylineno c_lineno
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define c_wrap() (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 190
#define YY_END_OF_BUFFER 191
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[576] =
    {   0,
        0,    0,  191,  189,  167,  168,  155,  189,    3,   88,
      161,  154,  189,  149,  150,  159,  158,  146,  157,  153,
      160,  103,  103,  147,  143,  162,  148,  163,  166,  189,
       88,   88,  151,  188,  152,  164,   88,   88,   88,   88,
       88,   88,   88,   88,   88,   88,   88,   88,   88,   88,
       88,   88,   88,   88,   88,   88,   88,   88,  144,  165,
      145,  156,  142,    0,   43,    0,    2,   88,  127,  186,
      187,  136,  128,    0,    0,  125,  133,  123,  134,  124,
      135,    0,  117,    1,  126,  138,  120,   96,    0,  105,
      104,    0,  103,  132,  139,  141,  140,  131,    0,    0,

        0,    0,    0,   88,  129,   88,   88,   88,   88,   88,
       88,   88,   88,    9,   88,   88,   88,   88,   88,   88,
       88,   13,   46,   88,   88,   88,   88,   88,   88,   88,
       88,   88,   88,   88,   88,   88,   88,   88,   88,   88,
       88,   88,   88,   88,   88,   88,   88,   88,   88,   88,
       88,   88,  130,  137,    0,    0,    2,  110,    4,    0,
      115,  116,  117,    0,  118,  119,   98,   97,    0,  114,
      106,  107,  107,   89,  122,  121,  175,  176,  173,  178,
      183,  174,  185,  184,  179,  182,  177,  180,  181,    0,
        0,    0,   44,    0,    0,    0,   88,   88,   88,   88,

       88,   88,   88,   88,   88,   88,   88,   88,   88,   88,
       88,   88,   88,   88,   11,   88,   88,   27,   88,   88,
       88,   88,   88,   88,   88,   88,   88,   88,   88,   45,
       88,   88,   88,   88,   88,   88,   88,   78,   88,   88,
       88,   88,   88,   88,   88,   88,   88,   88,   88,   88,
       88,   88,   88,   88,   88,   88,   88,   88,   88,    0,
       43,    0,    0,  117,    0,  115,  116,    0,  120,   99,
      100,  100,  112,  113,  109,  108,   90,   92,  171,  172,
        0,    0,    0,    0,  111,   88,   88,   88,   88,   39,
       88,    6,   29,   88,   88,   88,   88,   88,   88,   10,

       24,   88,   88,   88,   88,   12,   88,   88,   88,   53,
       88,   31,   88,   88,   88,   88,   54,   88,   88,   72,
       88,   88,   88,   88,   88,   88,   88,   88,   88,   88,
       88,   88,   88,   88,   88,   88,   88,   88,   88,   88,
       88,   88,   88,   88,   88,   88,   26,   88,   88,   88,
        0,  117,  102,  101,   91,   93,   93,    0,  170,    0,
       44,    0,   88,   88,   88,   88,    5,   88,   36,   88,
       88,   88,   88,   88,   88,   88,   30,   88,   88,   88,
       88,   88,   88,   88,   88,   88,   88,   88,   88,   88,
       73,   88,   88,   88,   88,   88,   88,   88,   88,   32,

       88,   88,   88,   88,   88,   88,   88,   88,   88,   88,
       81,   23,   88,   88,   88,   88,   88,   18,   80,   95,
       94,  169,   88,   84,   88,   88,   88,   88,   88,   88,
       88,   28,   88,   38,   88,   21,   88,   56,   82,   88,
       88,   86,   64,   88,   88,   88,   88,   88,   88,   88,
       88,   62,   88,   88,   14,   79,   34,   15,   88,   41,
       22,   17,   88,   88,   88,   88,   88,   76,   19,   20,
       88,   85,   88,   49,   68,   88,   88,    8,   88,   63,
       88,   88,   88,   66,   87,   55,   88,   88,   88,   88,
       47,   88,   88,   61,   88,   88,   48,   65,   88,   25,

       88,   88,   88,   42,   88,   69,    7,   88,   77,   88,
       88,   88,   88,   74,   16,   88,   40,   37,   88,   57,
       88,   33,   35,   88,   75,   58,   88,   88,   88,   88,
       88,   88,   71,   88,   88,   88,   88,   88,   88,   67,
       88,   88,   88,   88,   88,   88,   88,   88,   88,   88,
       50,   88,   88,   59,   88,   88,   70,   88,   60,   88,
       88,   83,   88,   88,   88,   88,   88,   88,   88,   88,
       52,   88,   88,   51,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        4,    4,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    5,    6,    7,    8,    9,   10,   11,   12,
       13,   14,   15,   16,   17,   18,   19,   20,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   22,   23,   24,
       25,   26,   27,   28,   29,   30,   31,   30,   32,   33,
       34,    8,    8,    8,   35,   36,   37,    8,    8,    8,
       38,   39,   40,   41,   42,    8,   43,   44,    8,   45,
       46,   47,   48,   49,   50,    1,   51,   52,   53,   54,

       55,   56,   57,   58,   59,    8,   60,   61,   62,   63,
       64,   65,    8,   66,   67,   68,   69,   70,   71,   72,
       73,   74,   75,   76,   77,   78,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[79] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    2,    1,    1,
        3,    1,    1,    1,    1,    1,    1,    1,    1,    4,
        4,    1,    1,    1,    1,    1,    1,    1,    5,    5,
        5,    5,    5,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    1,    1,    1,    1,    2,
        5,    5,    5,    5,    5,    5,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    1,    1,    1,    1
    } ;

static const flex_int16_t yy_base[586] =
    {   0,
        0,    0,  750,  751,  751,  751,  724,   73,    0,    0,
       55,   71,  701,  751,  751,  722,   67,  751,   68,   66,
       74,   80,   87,  751,  751,   65,  721,   77,  751,   99,
       98,  694,  751,  751,  751,  719,  693,   28,  676,   67,
       51,   73,   82,  677,   84,   55,  676,  688,   89,   98,
      687,  682,  105,  102,  673,   62,  677,  675,  751,   86,
      751,  751,  751,  132,  175,  730,    0,    0,  751,  751,
      751,  751,  751,  144,  163,  751,  751,  751,  751,  751,
      751,  714,  151,  751,  751,  751,  165,  172,  179,  167,
      144,    0,  198,  706,  751,  751,  751,  705,  239,  692,

      692,  176,  680,  654,  751,  669,  651,  655,  667,  654,
      160,  657,  157,  650,  651,  648,  164,  655,  651,  648,
      645,    0,  127,  649,  656,  649,  646,  636,  636,  638,
      644,  637,  647,  641,  633,  637,  633,  181,  642,  138,
      178,  642,  159,  637,  633,  625,  628,  191,  642,  195,
      632,  635,  751,  751,  259,  240,    0,  751,  751,  271,
      751,  751,  269,  278,  751,  751,  235,  203,  286,  290,
      182,  751,  233,  267,  751,  751,  751,  648,  659,  751,
      751,  751,  751,  751,  751,  751,  751,  751,  751,  648,
      649,  275,  310,  682,  274,  244,  275,  615,  615,  618,

      630,  625,  613,  625,  250,  626,  621,  623,  619,  611,
      608,  616,  603,  618,    0,  604,  608,  611,  596,  599,
      602,  605,  280,  595,  597,  598,  603,  590,  583,    0,
      600,  586,  600,  593,  203,  583,  581,    0,  583,  582,
      584,  591,  592,  576,  574,  574,  576,  585,  584,  580,
      582,  572,  576,  567,  246,  579,  581,  570,  569,  302,
      329,  626,  313,  317,  324,  751,  751,  322,  327,  285,
      751,  304,  751,  751,  751,  751,  316,  319,  751,  751,
      600,  588,  364,  350,  751,  571,  570,  561,  550,    0,
      562,    0,    0,  561,  552,  560,  549,  554,  555,    0,

        0,  548,  548,  558,  544,    0,  548,  553,  548,    0,
       73,    0,  553,  552,  551,  536,  291,  538,  548,    0,
      548,  542,  536,  532,  543,  528,  530,  529,  539,  525,
      537,  527,  531,  530,  535,  534,  520,  522,  530,  528,
      526,  518,  523,  524,  512,  524,    0,  508,  520,  520,
      348,  351,  751,  751,  322,  751,  321,  545,  751,  355,
      373,  569,  520,  502,  516,  503,    0,  319,    0,  504,
      505,  511,  509,  508,  499,  498,    0,  505,  493,  497,
      503,  501,  504,  486,  497,  491,  496,  492,  479,  480,
        0,  496,  477,  477,  488,  482,  483,  478,  486,    0,

      485,  482,  486,  483,  467,  476,  478,  463,  476,  477,
        0,    0,  466,  474,  470,  465,  466,    0,    0,  751,
      751,  751,  470,    0,  473,  467,  467,  456,  450,  450,
      462,    0,  462,  464,  445,    0,  462,    0,    0,  456,
      457,    0,    0,  449,  443,  453,  452,  442,  444,  441,
      448,    0,  441,  448,    0,    0,  441,    0,  438,    0,
        0,    0,  442,  436,  440,  435,  439,    0,    0,    0,
      432,    0,  442,    0,  424,  436,  434,    0,  425,    0,
      426,  425,  424,    0,    0,    0,  422,  420,  416,  425,
        0,  412,  413,    0,  410,  414,    0,    0,  415,    0,

      420,  420,  418,    0,  404,    0,    0,  403,    0,  409,
      401,  409,   27,    0,    0,  412,    0,    0,  398,    0,
      411,  405,    0,  397,    0,    0,  389,  398,  409,  393,
      404,  402,    0,  381,  373,  363,  372,  359,  350,    0,
      354,  342,  356,  353,  338,  338,  349,  337,  346,  332,
        0,  344,  343,    0,  345,  338,    0,  340,    0,  332,
      326,    0,  322,  338,  313,  268,  198,  175,  176,  144,
        0,  100,  104,    0,  751,  412,  416,  420,  425,  429,
      431,  436,  441,  446,  451
    } ;

static const flex_int16_t yy_def[586] =
    {   0,
      575,    1,  575,  575,  575,  575,  575,  576,  577,  578,
      575,  575,  579,  575,  575,  575,  575,  575,  575,  575,
      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,
      578,  578,  575,  575,  575,  575,  578,  578,  578,  578,
      578,  578,  578,  578,  578,  578,  578,  578,  578,  578,
      578,  578,  578,  578,  578,  578,  578,  578,  575,  575,
      575,  575,  575,  576,  575,  576,  580,  578,  575,  575,
      575,  575,  575,  579,  579,  575,  575,  575,  575,  575,
      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,
      575,  581,  575,  575,  575,  575,  575,  575,  575,  575,

      575,  582,  583,  578,  575,  578,  578,  578,  578,  578,
      578,  578,  578,  578,  578,  578,  578,  578,  578,  578,
      578,  578,  578,  578,  578,  578,  578,  578,  578,  578,
      578,  578,  578,  578,  578,  578,  578,  578,  578,  578,
      578,  578,  578,  578,  578,  578,  578,  578,  578,  578,
      578,  578,  575,  575,  575,  584,  580,  575,  575,  575,
      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,
      575,  575,  575,  581,  575,  575,  575,  575,  575,  575,
      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,
      575,  582,  575,  582,  583,  583,  578,  578,  578,  578,

      578,  578,  578,  578,  578,  578,  578,  578,  578,  578,
      578,  578,  578,  578,  578,  578,  578,  578,  578,  578,
      578,  578,  578,  578,  578,  578,  578,  578,  578,  578,
      578,  578,  578,  578,  578,  578,  578,  578,  578,  578,
      578,  578,  578,  578,  578,  578,  578,  578,  578,  578,
      578,  578,  578,  578,  578,  578,  578,  578,  578,  584,
      575,  584,  575,  575,  575,  575,  575,  575,  575,  575,
      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,
      575,  575,  575,  585,  575,  578,  578,  578,  578,  578,
      578,  578,  578,  578,  578,  578,  578,  578,  578,  578,

      578,  578,  578,  578,  578,  578,  578,  578,  578,  578,
      578,  578,  578,  578,  578,  578,  578,  578,  578,  578,
      578,  578,  578,  578,  578,  578,  578,  578,  578,  578,
      578,  578,  578,  578,  578,  578,  578,  578,  578,  578,
      578,  578,  578,  578,  578,  578,  578,  578,  578,  578,
      575,  575,  575,  575,  575,  575,  575,  575,  575,  585,
      575,  585,  578,  578,  578,  578,  578,  578,  578,  578,
      578,  578,  578,  578,  578,  578,  578,  578,  578,  578,
      578,  578,  578,  578,  578,  578,  578,  578,  578,  578,
      578,  578,  578,  578,  578,  578,  578,  578,  578,  578,

      578,  578,  578,  578,  578,  578,  578,  578,  578,  578,
      578,  578,  578,  578,  578,  578,  578,  578,  578,  575,
      575,  575,  578,  578,  578,  578,  578,  578,  578,  578,
      578,  578,  578,  578,  578,  578,  578,  578,  578,  578,
      578,  578,  578,  578,  578,  578,  578,  578,  578,  578,
      578,  578,  578,  578,  578,  578,  578,  578,  578,  578,
      578,  578,  578,  578,  578,  578,  578,  578,  578,  578,
      578,  578,  578,  578,  578,  578,  578,  578,  578,  578,
      578,  578,  578,  578,  578,  578,  578,  578,  578,  578,
      578,  578,  578,  578,  578,  578,  578,  578,  578,  578,

      578,  578,  578,  578,  578,  578,  578,  578,  578,  578,
      578,  578,  578,  578,  578,  578,  578,  578,  578,  578,
      578,  578,  578,  578,  578,  578,  578,  578,  578,  578,
      578,  578,  578,  578,  578,  578,  578,  578,  578,  578,
      578,  578,  578,  578,  578,  578,  578,  578,  578,  578,
      578,  578,  578,  578,  578,  578,  578,  578,  578,  578,
      578,  578,  578,  578,  578,  578,  578,  578,  578,  578,
      578,  578,  578,  578,    0,  575,  575,  575,  575,  575,
      575,  575,  575,  575,  575
    } ;

static const flex_int16_t yy_nxt[830] =
    {   0,
        4,    5,    6,    5,    7,    8,    9,   10,   11,   12,
       13,   14,   15,   16,   17,   18,   19,   20,   21,   22,
       23,   24,   25,   26,   27,   28,   29,   30,   10,   10,
       10,   10,   10,   10,   10,   31,   32,   10,   10,   10,
       10,   10,   10,   10,   10,   33,   34,   35,   36,   37,
       38,   39,   40,   41,   42,   43,   44,   10,   45,   46,
       47,   48,   49,   50,   51,   52,   53,   54,   55,   56,
       57,   10,   58,   10,   59,   60,   61,   62,   65,   69,
       72,   77,  529,   82,   79,   83,   83,   84,   94,   95,
      107,   78,   80,   81,  530,   73,  108,   87,   85,   88,

       88,   97,   98,  102,   87,  113,   93,   93,  103,  125,
      153,   89,  149,  126,  114,   90,   99,  110,   89,   66,
       86,   91,   90,   92,  111,  150,  100,  381,   91,   70,
      112,   71,  118,  115,   89,  116,  101,   65,  382,  122,
       90,   89,  119,  129,  117,  120,  123,   90,   91,  132,
      124,   92,  130,  133,  158,   91,  145,  131,  574,  139,
      134,  154,  140,  141,  573,  575,  135,  146,  136,  142,
       83,   83,  143,   74,  147,  144,  155,  155,   66,  173,
      156,  193,  160,  161,  163,  163,  162,  217,  239,   87,
       75,   88,   88,  169,  218,  169,  164,  165,  170,  170,

      166,  240,  171,   89,  173,  160,  161,  167,  172,  244,
      203,  162,  206,  168,  204,   87,  572,   93,   93,  164,
      165,  207,  194,  275,  245,  166,   89,  171,  211,   89,
      571,  212,  167,   90,  241,  172,  233,  234,  272,   91,
      168,  235,  570,  250,  251,  261,  575,  236,  237,  252,
      275,  242,   89,  256,  195,  257,  325,  253,   90,  254,
      155,  155,  569,  272,  156,  326,   91,  177,  276,  178,
      270,  179,  180,  181,  182,  183,  271,  184,  185,  186,
      193,  187,  188,  189,  285,  263,  262,  263,  163,  163,
      264,  264,  268,  276,  268,  270,  345,  269,  269,  346,

      265,  266,  277,  271,  267,  170,  170,  261,  278,  170,
      170,  283,  283,  286,  287,  284,  295,  296,  313,  314,
      196,  194,  273,  265,  266,  274,  353,  277,  568,  267,
      155,  155,  264,  264,  156,  278,  264,  264,  351,  354,
      351,  269,  269,  352,  352,  273,  269,  269,  262,  161,
      274,  355,  162,  353,  357,  361,  421,  356,  387,  165,
      361,  388,  166,  420,  354,  283,  283,  352,  352,  284,
      352,  352,  161,  427,  283,  283,  355,  162,  284,  357,
      428,  421,  165,  266,  356,  567,  267,  166,  566,  565,
      420,  564,  563,  562,  561,  560,  362,  559,  558,  557,

      556,  362,  555,  554,  553,  552,  266,  551,  550,  549,
      548,  267,   64,   64,   64,   64,   64,   67,  547,  546,
       67,   68,  545,   68,   68,   74,   74,  544,   74,   74,
      157,  543,  157,  157,  174,  174,  192,  192,  192,  192,
      192,  195,  195,  542,  195,  195,  260,  260,  260,  260,
      260,  360,  360,  360,  360,  360,  541,  540,  539,  538,
      537,  536,  535,  534,  533,  532,  531,  528,  527,  526,
      525,  524,  523,  522,  521,  520,  519,  518,  517,  516,
      515,  514,  513,  512,  511,  510,  509,  508,  507,  506,
      505,  504,  503,  502,  501,  500,  499,  498,  497,  496,

      495,  494,  493,  492,  491,  490,  489,  488,  487,  486,
      485,  484,  483,  482,  481,  480,  479,  478,  477,  476,
      475,  474,  473,  472,  471,  470,  469,  468,  467,  466,
      465,  464,  463,  462,  461,  460,  459,  458,  457,  456,
      455,  454,  453,  452,  451,  450,  449,  448,  447,  446,
      445,  444,  443,  442,  441,  440,  439,  438,  437,  436,
      435,  434,  433,  432,  431,  430,  429,  426,  425,  424,
      423,  575,  422,  419,  418,  417,  416,  415,  414,  413,
      412,  411,  410,  409,  408,  407,  406,  405,  404,  403,
      402,  401,  400,  399,  398,  397,  396,  395,  394,  393,

      392,  391,  390,  389,  386,  385,  384,  383,  380,  379,
      378,  377,  376,  375,  374,  373,  372,  371,  370,  369,
      368,  367,  366,  365,  364,  363,  359,  358,  575,  350,
      349,  348,  347,  344,  343,  342,  341,  340,  339,  338,
      337,  336,  335,  334,  333,  332,  331,  330,  329,  328,
      327,  324,  323,  322,  321,  320,  319,  318,  317,  316,
      315,  312,  311,  310,  309,  308,  307,  306,  305,  304,
      303,  302,  301,  300,  299,  298,  297,  294,  293,  292,
      291,  290,  289,  288,  575,  282,  281,  280,  279,  259,
      258,  255,  249,  248,  247,  246,  243,  238,  232,  231,

      230,  229,  228,  227,  226,  225,  224,  223,  222,  221,
      220,  219,  216,  215,  214,  213,  210,  209,  208,  205,
      202,  201,  200,  199,  198,  197,  196,  191,  190,  176,
      175,  159,  575,  152,  151,  148,  138,  137,  128,  127,
      121,  109,  106,  105,  104,   96,   76,   75,   63,  575,
        3,  575,  575,  575,  575,  575,  575,  575,  575,  575,
      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,
      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,
      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,
      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,

      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,
      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,
      575,  575,  575,  575,  575,  575,  575,  575,  575
    } ;

static const flex_int16_t yy_chk[830] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    8,   11,
       12,   17,  513,   20,   19,   20,   20,   21,   26,   26,
       38,   17,   19,   19,  513,   12,   38,   22,   21,   22,

       22,   28,   28,   31,   23,   41,   23,   23,   31,   46,
       60,   22,   56,   46,   41,   22,   30,   40,   23,    8,
       21,   22,   23,   22,   40,   56,   30,  311,   23,   11,
       40,   11,   43,   42,   22,   42,   30,   64,  311,   45,
       22,   23,   43,   49,   42,   43,   45,   23,   22,   50,
       45,   22,   49,   50,   74,   23,   54,   49,  573,   53,
       50,   60,   53,   53,  572,   75,   50,   54,   50,   53,
       83,   83,   53,   75,   54,   53,   65,   65,   64,   91,
       65,  102,   83,   83,   87,   87,   83,  123,  140,   88,
       74,   88,   88,   89,  123,   89,   87,   87,   89,   89,

       87,  140,   90,   88,   91,   83,   83,   88,   90,  143,
      111,   83,  113,   88,  111,   93,  570,   93,   93,   87,
       87,  113,  102,  171,  143,   87,   88,   90,  117,   93,
      569,  117,   88,   93,  141,   90,  138,  138,  168,   93,
       88,  138,  568,  148,  148,  156,  196,  138,  138,  148,
      171,  141,   93,  150,  196,  150,  235,  148,   93,  148,
      155,  155,  567,  168,  155,  235,   93,   99,  173,   99,
      167,   99,   99,   99,   99,   99,  167,   99,   99,   99,
      192,   99,   99,   99,  195,  160,  156,  160,  163,  163,
      160,  160,  164,  173,  164,  167,  255,  164,  164,  255,

      163,  163,  174,  167,  163,  169,  169,  260,  174,  170,
      170,  193,  193,  197,  197,  193,  205,  205,  223,  223,
      195,  192,  170,  163,  163,  170,  270,  174,  566,  163,
      261,  261,  263,  263,  261,  174,  264,  264,  265,  272,
      265,  268,  268,  265,  265,  170,  269,  269,  260,  264,
      170,  277,  264,  270,  278,  284,  357,  277,  317,  269,
      360,  317,  269,  355,  272,  283,  283,  351,  351,  283,
      352,  352,  264,  368,  361,  361,  277,  264,  361,  278,
      368,  357,  269,  352,  277,  565,  352,  269,  564,  563,
      355,  561,  560,  558,  556,  555,  284,  553,  552,  550,

      549,  360,  548,  547,  546,  545,  352,  544,  543,  542,
      541,  352,  576,  576,  576,  576,  576,  577,  539,  538,
      577,  578,  537,  578,  578,  579,  579,  536,  579,  579,
      580,  535,  580,  580,  581,  581,  582,  582,  582,  582,
      582,  583,  583,  534,  583,  583,  584,  584,  584,  584,
      584,  585,  585,  585,  585,  585,  532,  531,  530,  529,
      528,  527,  524,  522,  521,  519,  516,  512,  511,  510,
      508,  505,  503,  502,  501,  499,  496,  495,  493,  492,
      490,  489,  488,  487,  483,  482,  481,  479,  477,  476,
      475,  473,  471,  467,  466,  465,  464,  463,  459,  457,

      454,  453,  451,  450,  449,  448,  447,  446,  445,  444,
      441,  440,  437,  435,  434,  433,  431,  430,  429,  428,
      427,  426,  425,  423,  417,  416,  415,  414,  413,  410,
      409,  408,  407,  406,  405,  404,  403,  402,  401,  399,
      398,  397,  396,  395,  394,  393,  392,  390,  389,  388,
      387,  386,  385,  384,  383,  382,  381,  380,  379,  378,
      376,  375,  374,  373,  372,  371,  370,  366,  365,  364,
      363,  362,  358,  350,  349,  348,  346,  345,  344,  343,
      342,  341,  340,  339,  338,  337,  336,  335,  334,  333,
      332,  331,  330,  329,  328,  327,  326,  325,  324,  323,

      322,  321,  319,  318,  316,  315,  314,  313,  309,  308,
      307,  305,  304,  303,  302,  299,  298,  297,  296,  295,
      294,  291,  289,  288,  287,  286,  282,  281,  262,  259,
      258,  257,  256,  254,  253,  252,  251,  250,  249,  248,
      247,  246,  245,  244,  243,  242,  241,  240,  239,  237,
      236,  234,  233,  232,  231,  229,  228,  227,  226,  225,
      224,  222,  221,  220,  219,  218,  217,  216,  214,  213,
      212,  211,  210,  209,  208,  207,  206,  204,  203,  202,
      201,  200,  199,  198,  194,  191,  190,  179,  178,  152,
      151,  149,  147,  146,  145,  144,  142,  139,  137,  136,

      135,  134,  133,  132,  131,  130,  129,  128,  127,  126,
      125,  124,  121,  120,  119,  118,  116,  115,  114,  112,
      110,  109,  108,  107,  106,  104,  103,  101,  100,   98,
       94,   82,   66,   58,   57,   55,   52,   51,   48,   47,
       44,   39,   37,   36,   32,   27,   16,   13,    7,    3,
      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,
      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,
      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,
      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,
      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,

      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,
      575,  575,  575,  575,  575,  575,  575,  575,  575,  575,
      575,  575,  575,  575,  575,  575,  575,  575,  575
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "cscanner.l"
/*;-*-C-*-; 
** Splint - annotation-assisted static program checker
** Copyright (C) 1994-2003 University of Virginia,
**         Massachusetts Institute of Technology
**
** This program is free software; you can redistribute it and/or modify it
** under the terms of the GNU General Public License as published by the
** Free Software Foundation; either version 2 of the License, or (at your
** option) any later version.
** 
** This program is distributed in the hope that it will be useful, but
** WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
** General Public License for more details.
** 
** The GNU General Public License is available from http://www.gnu.org/ or
** the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
** MA 02111-1307, USA.
**
** For information on splint: splint@cs.virginia.edu
** To report a bug: splint-bug@cs.virginia.edu
** For more information: http://www.splint.org
*/
/*
** cscanner.l
**
** Flex lexer for C.
** Based on a C lexer by Nate Osgood
**    from hacrat@catfish.lcs.mit.edu Mon Jun 14 13:06:32 1993
*/
/*
** Modified by Mike Smith 
** Corrected missing 'line' in scanf() calls in handleSpecial().
** Without this, I get an error when Splint hits a '#line' directive
** in the pre-pre-processed source files.
**
** Modified by Mike Smith, 4th June 1997
** Finally resolved the #line problem.  The scanf() calls have been fixed to
** allow the following #line forms:-
**
**        #line 123 "filename"
**        #line 123
**        # 123 "filename"
**        # 123
**
** The last two are generated by the GNU pre-processor, apparently
*/
#line 61 "cscanner.l"
# include "splintMacros.nf"
# include "basic.h"

# include "cscannerHelp.h"
# include "cgrammar.h"

/*@notfunction@*/
# define yyinput() (incColumn (), getc (yyin))

# include "flex.head"

#line 1137 "cscanner.c"
/* prefix option above would transform outfile to "lex.c_.c";
 * sadly, auto{conf,make} expect "lex.yy.c" */
#line 1140 "cscanner.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  );
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 84 "cscanner.l"


#line 1360 "cscanner.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 576 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 575 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 86 "cscanner.l"
{ llfatalerror (cstring_makeLiteral ("Comment in pre-processor output")); }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 88 "cscanner.l"
{  
                 context_saveLocation (); 
                 cscannerHelp_setTokLengthT (mstring_length (yytext)); 

                 if (cscannerHelp_processHashIdentifier 
		     (cscannerHelp_makeIdentifier (yytext + 1)))
                   {
		     return cscannerHelp_returnString (cstring_makeLiteral (""));
		   }
                 else
                   { 
		     if (cscannerHelp_handleSpecial (yytext)) 
                       { 
                         return cscannerHelp_returnTokenLength (0, 1);
		       }
		   }
                } 
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 105 "cscanner.l"
{ if (cscannerHelp_handleSpecial (yytext)) 
                    { 
                      return cscannerHelp_returnTokenLength (0, 1);
                    }
                }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 110 "cscanner.l"
{ return cscannerHelp_returnTokenLength (CTOK_ELIPSIS, 3); }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 111 "cscanner.l"
{ return cscannerHelp_returnTokenLength (BREAK, 5); }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 112 "cscanner.l"
{ return cscannerHelp_returnTokenLength (CASE, 4); }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 113 "cscanner.l"
{ return cscannerHelp_returnTokenLength (CONTINUE, 8); }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 114 "cscanner.l"
{ return cscannerHelp_returnTokenLength (DEFAULT, 7); }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 115 "cscanner.l"
{ return cscannerHelp_returnTokenLength (DO, 2); }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 116 "cscanner.l"
{ return cscannerHelp_returnTokenLength (CELSE, 4); }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 117 "cscanner.l"
{ return cscannerHelp_returnTokenLength (CFOR, 3); }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 118 "cscanner.l"
{ return cscannerHelp_returnTokenLength (GOTO, 4); }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 119 "cscanner.l"
{ return cscannerHelp_returnTokenLength (CIF, 2); }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 120 "cscanner.l"
{ return cscannerHelp_returnTokenLength (RETURN, 6); }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 121 "cscanner.l"
{ return cscannerHelp_returnTokenLength (CSIZEOF, 6); }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 122 "cscanner.l"
{ return cscannerHelp_returnTokenLength (COFFSETOF, 8); }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 123 "cscanner.l"
{ return cscannerHelp_returnTokenLength (SWITCH, 6); }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 124 "cscanner.l"
{ return cscannerHelp_returnTokenLength (WHILE, 5); }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 125 "cscanner.l"
{ return cscannerHelp_returnTokenLength (VA_ARG, 6); }   
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 126 "cscanner.l"
{ return cscannerHelp_returnTokenLength (VA_DCL, 6); }   
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 127 "cscanner.l"
{ return cscannerHelp_returnTokenLength (QINLINE, 6); }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 129 "cscanner.l"
{ return cscannerHelp_returnTokenLength (CSTRUCT, 6); }  
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 130 "cscanner.l"
{ return cscannerHelp_returnTokenLength (CUNION, 5); }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 131 "cscanner.l"
{ return cscannerHelp_returnTokenLength (CENUM, 4); }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 132 "cscanner.l"
{ return cscannerHelp_returnTokenLength (CTYPEDEF, 7); }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 134 "cscanner.l"
{ cscannerHelp_setTokLength (4); return cscannerHelp_returnType (CVOID, ctype_void); }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 135 "cscanner.l"
{ cscannerHelp_setTokLength (3); return cscannerHelp_returnType (CINT, ctype_int); }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 136 "cscanner.l"
{ cscannerHelp_setTokLength (6); return cscannerHelp_returnType (CDOUBLE, ctype_double); }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 137 "cscanner.l"
{ cscannerHelp_setTokLength (4); return cscannerHelp_returnType (CGCHAR, ctype_char); }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 138 "cscanner.l"
{ cscannerHelp_setTokLength (5); return cscannerHelp_returnType (CGFLOAT, ctype_float); }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 140 "cscanner.l"
{ return cscannerHelp_returnTokenLength (QLONG, 4); }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 141 "cscanner.l"
{ return cscannerHelp_returnTokenLength (QSHORT, 5); }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 142 "cscanner.l"
{ return cscannerHelp_returnTokenLength (QUNSIGNED, 8); }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 143 "cscanner.l"
{ return cscannerHelp_returnTokenLength (QSIGNED, 6); }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 145 "cscanner.l"
{ return cscannerHelp_returnTokenLength (QVOLATILE, 8); }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 146 "cscanner.l"
{ return cscannerHelp_returnTokenLength (QCONST, 5); }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 147 "cscanner.l"
{ return cscannerHelp_returnTokenLength (QRESTRICT, 8); }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 149 "cscanner.l"
{ return cscannerHelp_returnTokenLength (QEXTERN, 6); }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 150 "cscanner.l"
{ return cscannerHelp_returnTokenLength (QAUTO, 4); }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 151 "cscanner.l"
{ return cscannerHelp_returnTokenLength (QREGISTER, 8); }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 152 "cscanner.l"
{ return cscannerHelp_returnTokenLength (QSTATIC, 6); }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 154 "cscanner.l"
{ cscannerHelp_setTokLength (8); return cscannerHelp_returnFunctionName (yytext); }
	YY_BREAK
case 43:
/* rule 43 can match eol */
YY_RULE_SETUP
#line 156 "cscanner.l"
{ return cscannerHelp_returnExpr (cscannerHelp_processString ()); }
	YY_BREAK
case 44:
/* rule 44 can match eol */
YY_RULE_SETUP
#line 157 "cscanner.l"
{ return cscannerHelp_returnExpr (cscannerHelp_processWideString ()); }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 159 "cscanner.l"
{ return (cscannerHelp_processSpec (QOUT)); }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 160 "cscanner.l"
{ return (cscannerHelp_processSpec (QIN)); }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 161 "cscanner.l"
{ return (cscannerHelp_processSpec (QPARTIAL)); }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 162 "cscanner.l"
{ return (cscannerHelp_processSpec (QSPECIAL)); }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 163 "cscanner.l"
{ return (cscannerHelp_processSpec (QANYTYPE)); }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 164 "cscanner.l"
{ return (cscannerHelp_processSpec (QINTEGRALTYPE)); }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 165 "cscanner.l"
{ return (cscannerHelp_processSpec (QUNSIGNEDINTEGRALTYPE)); }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 166 "cscanner.l"
{ return (cscannerHelp_processSpec (QSIGNEDINTEGRALTYPE)); }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 167 "cscanner.l"
{ return (cscannerHelp_processSpec (QKEEP)); }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 168 "cscanner.l"
{ return (cscannerHelp_processSpec (QNULL)); } 
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 169 "cscanner.l"
{ return (cscannerHelp_processSpec (QNOTNULL)); } 
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 170 "cscanner.l"
{ return (cscannerHelp_processSpec (QISNULL)); } 
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 171 "cscanner.l"
{ return (cscannerHelp_processSpec (QTRUENULL)); } 
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 172 "cscanner.l"
{ return (cscannerHelp_processSpec (QFALSENULL)); } 
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 173 "cscanner.l"
{ return (cscannerHelp_processSpec (QTRUENULL)); } 
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 174 "cscanner.l"
{ return (cscannerHelp_processSpec (QFALSENULL)); } 
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 175 "cscanner.l"
{ return (cscannerHelp_processSpec (QRELNULL)); }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 176 "cscanner.l"
{ return (cscannerHelp_processSpec (QRELDEF)); }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 177 "cscanner.l"
{ return (cscannerHelp_processSpec (QEXPOSED)); }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 178 "cscanner.l"
{ return (cscannerHelp_processSpec (QNEWREF)); }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 179 "cscanner.l"
{ return (cscannerHelp_processSpec (QTEMPREF)); }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 180 "cscanner.l"
{ return (cscannerHelp_processSpec (QKILLREF)); }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 181 "cscanner.l"
{ return (cscannerHelp_processSpec (QREFCOUNTED)); }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 182 "cscanner.l"
{ return (cscannerHelp_processSpec (QCHECKED)); }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 183 "cscanner.l"
{ return (cscannerHelp_processSpec (QCHECKMOD)); }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 184 "cscanner.l"
{ return (cscannerHelp_processSpec (QCHECKEDSTRICT)); }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 185 "cscanner.l"
{ return (cscannerHelp_processSpec (QUNCHECKED)); }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 186 "cscanner.l"
{ return (cscannerHelp_processSpec (QONLY)); }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 187 "cscanner.l"
{ return (cscannerHelp_processSpec (QOWNED)); }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 188 "cscanner.l"
{ return (cscannerHelp_processSpec (QOBSERVER)); }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 189 "cscanner.l"
{ return (cscannerHelp_processSpec (QDEPENDENT)); }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 190 "cscanner.l"
{ return (cscannerHelp_processSpec (QUNUSED)); }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 191 "cscanner.l"
{ return (cscannerHelp_processSpec (QEXTERNAL)); }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 192 "cscanner.l"
{ return (cscannerHelp_processSpec (QSEF)); }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 193 "cscanner.l"
{ return (cscannerHelp_processSpec (QSHARED)); }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 194 "cscanner.l"
{ return (cscannerHelp_processSpec (QYIELD)); }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 195 "cscanner.l"
{ return (cscannerHelp_processSpec (QUNDEF)); }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 196 "cscanner.l"
{ return (cscannerHelp_processSpec (QKILLED)); }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 197 "cscanner.l"
{ return (cscannerHelp_processSpec (QNULLTERMINATED));}
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 198 "cscanner.l"
{ return (cscannerHelp_processSpec (QMAXSET));}
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 199 "cscanner.l"
{ return (cscannerHelp_processSpec (QMAXREAD));}
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 200 "cscanner.l"
{ return (cscannerHelp_processSpec (QMAXSET));}
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 201 "cscanner.l"
{ return (cscannerHelp_processSpec (QMAXREAD));}
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 203 "cscanner.l"
{ int tok = cscannerHelp_processTextIdentifier (yytext);
                              if (tok != BADTOK)
				{
				  return (tok);
				}
			    }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 209 "cscanner.l"
{ cscannerHelp_setTokLengthT (mstring_length (yytext)); 
                          return cscannerHelp_returnInt (ctype_int, cscannerHelp_processHex ()); }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 211 "cscanner.l"
{ cscannerHelp_setTokLengthT (mstring_length (yytext)); 
			  return cscannerHelp_returnInt (ctype_lint, cscannerHelp_processHex ()); }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 213 "cscanner.l"
{ cscannerHelp_setTokLengthT (mstring_length (yytext)); 
			  return cscannerHelp_returnInt (ctype_llint, cscannerHelp_processHex ()); }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 215 "cscanner.l"
{ cscannerHelp_setTokLengthT (mstring_length (yytext)); 
                          return cscannerHelp_returnInt (ctype_uint, cscannerHelp_processHex ()); }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 217 "cscanner.l"
{ cscannerHelp_setTokLengthT (mstring_length (yytext)); 
			  return cscannerHelp_returnInt (ctype_ulint, cscannerHelp_processHex ()); }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 219 "cscanner.l"
{ cscannerHelp_setTokLengthT (mstring_length (yytext)); 
			  return cscannerHelp_returnInt (ctype_ullint, cscannerHelp_processHex ()); }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 221 "cscanner.l"
{ cscannerHelp_setTokLengthT (mstring_length (yytext)); 
			  return cscannerHelp_returnInt (ctype_ullint, cscannerHelp_processHex ()); }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 223 "cscanner.l"
{ cscannerHelp_setTokLengthT (mstring_length (yytext)); 
			  return cscannerHelp_returnInt (ctype_int, cscannerHelp_processOctal ()); } 
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 225 "cscanner.l"
{ cscannerHelp_setTokLengthT (mstring_length (yytext)); 
		 	  return cscannerHelp_returnInt (ctype_uint, cscannerHelp_processOctal ()); } 
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 227 "cscanner.l"
{ cscannerHelp_setTokLengthT (mstring_length (yytext)); 
 		          return cscannerHelp_returnInt (ctype_lint, cscannerHelp_processOctal ()); } 
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 229 "cscanner.l"
{ cscannerHelp_setTokLengthT (mstring_length (yytext)); 
 		          return cscannerHelp_returnInt (ctype_llint, cscannerHelp_processOctal ()); } 
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 231 "cscanner.l"
{ cscannerHelp_setTokLengthT (mstring_length (yytext)); 
	   	          return cscannerHelp_returnInt (ctype_ulint, cscannerHelp_processOctal ()); } 
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 233 "cscanner.l"
{ cscannerHelp_setTokLengthT (mstring_length (yytext)); 
	   	          return cscannerHelp_returnInt (ctype_ullint, cscannerHelp_processOctal ()); } 
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 235 "cscanner.l"
{ cscannerHelp_setTokLengthT (mstring_length (yytext)); 
	   	          return cscannerHelp_returnInt (ctype_ullint, cscannerHelp_processOctal ()); } 
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 237 "cscanner.l"
{ cscannerHelp_setTokLengthT (mstring_length (yytext)); 
		         return cscannerHelp_returnInt (ctype_int, cscannerHelp_processDec ()); } 
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 239 "cscanner.l"
{ cscannerHelp_setTokLengthT (mstring_length (yytext)); 
		         return cscannerHelp_returnInt (ctype_uint, cscannerHelp_processDec ()); } 
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 241 "cscanner.l"
{ cscannerHelp_setTokLengthT (mstring_length (yytext)); 
	      	         return cscannerHelp_returnInt (ctype_lint, cscannerHelp_processDec ()); } 
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 243 "cscanner.l"
{ cscannerHelp_setTokLengthT (mstring_length (yytext)); 
	      	         return cscannerHelp_returnInt (ctype_llint, cscannerHelp_processDec ()); } 
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 245 "cscanner.l"
{ cscannerHelp_setTokLengthT (mstring_length (yytext)); 
	    	         return cscannerHelp_returnInt (ctype_ulint, cscannerHelp_processDec ()); } 
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 247 "cscanner.l"
{ cscannerHelp_setTokLengthT (mstring_length (yytext)); 
	    	         return cscannerHelp_returnInt (ctype_ullint, cscannerHelp_processDec ()); } 
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 249 "cscanner.l"
{ cscannerHelp_setTokLengthT (mstring_length (yytext)); 
	    	         return cscannerHelp_returnInt (ctype_ullint, cscannerHelp_processDec ()); } 
	YY_BREAK
case 110:
/* rule 110 can match eol */
YY_RULE_SETUP
#line 251 "cscanner.l"
{ cscannerHelp_setTokLengthT (mstring_length (yytext)); 
                         return cscannerHelp_returnChar (cscannerHelp_processChar ()); }
	YY_BREAK
case 111:
/* rule 111 can match eol */
YY_RULE_SETUP
#line 253 "cscanner.l"
{ cscannerHelp_setTokLengthT (mstring_length (yytext)); 
                         return cscannerHelp_returnChar (cscannerHelp_processChar ()); }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 255 "cscanner.l"
{ cscannerHelp_setTokLengthT (mstring_length (yytext)); 
			 return cscannerHelp_returnFloat (ctype_float, cscannerHelp_processFloat ()); }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 257 "cscanner.l"
{ cscannerHelp_setTokLengthT (mstring_length (yytext)); 
			 return cscannerHelp_returnFloat (ctype_ldouble, cscannerHelp_processFloat ()); }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 259 "cscanner.l"
{ cscannerHelp_setTokLengthT (mstring_length (yytext)); 
			 return cscannerHelp_returnFloat (ctype_double, cscannerHelp_processFloat ()); }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 262 "cscanner.l"
{ cscannerHelp_setTokLengthT (mstring_length (yytext)); 
				return cscannerHelp_returnFloat (ctype_float, cscannerHelp_processFloat ()); }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 264 "cscanner.l"
{ cscannerHelp_setTokLengthT (mstring_length (yytext)); 
				return cscannerHelp_returnFloat (ctype_ldouble, cscannerHelp_processFloat ()); }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 266 "cscanner.l"
{ cscannerHelp_setTokLengthT (mstring_length (yytext)); 
				return cscannerHelp_returnFloat (ctype_double, cscannerHelp_processFloat ()); }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 269 "cscanner.l"
{ cscannerHelp_setTokLengthT (mstring_length (yytext)); 
				  return cscannerHelp_returnFloat (ctype_float, cscannerHelp_processFloat ()); }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 271 "cscanner.l"
{ cscannerHelp_setTokLengthT (mstring_length (yytext)); 
				  return cscannerHelp_returnFloat (ctype_ldouble, cscannerHelp_processFloat ()); }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 273 "cscanner.l"
{ cscannerHelp_setTokLengthT (mstring_length (yytext)); 
				  return cscannerHelp_returnFloat (ctype_double, cscannerHelp_processFloat ()); }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 276 "cscanner.l"
{ return cscannerHelp_returnTokenLength (RIGHT_ASSIGN, 3); }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 277 "cscanner.l"
{ return cscannerHelp_returnTokenLength (LEFT_ASSIGN, 3); }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 278 "cscanner.l"
{ return cscannerHelp_returnTokenLength (ADD_ASSIGN, 2); }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 279 "cscanner.l"
{ return cscannerHelp_returnTokenLength (SUB_ASSIGN, 2); }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 280 "cscanner.l"
{ return cscannerHelp_returnTokenLength (MUL_ASSIGN, 2); }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 281 "cscanner.l"
{ return cscannerHelp_returnTokenLength (DIV_ASSIGN, 2); }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 282 "cscanner.l"
{ return cscannerHelp_returnTokenLength (MOD_ASSIGN, 2); }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 283 "cscanner.l"
{ return cscannerHelp_returnTokenLength (AND_ASSIGN, 2); }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 284 "cscanner.l"
{ return cscannerHelp_returnTokenLength (XOR_ASSIGN, 2); }
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 285 "cscanner.l"
{ return cscannerHelp_returnTokenLength (OR_ASSIGN, 2); }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 286 "cscanner.l"
{ return cscannerHelp_returnTokenLength (RIGHT_OP, 2); }
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 287 "cscanner.l"
{ return cscannerHelp_returnTokenLength (LEFT_OP, 2); }
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 288 "cscanner.l"
{ return cscannerHelp_returnTokenLength (INC_OP, 2); }
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 289 "cscanner.l"
{ return cscannerHelp_returnTokenLength (DEC_OP, 2); }
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 290 "cscanner.l"
{ return cscannerHelp_returnTokenLength (ARROW_OP, 2); }
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 291 "cscanner.l"
{ return cscannerHelp_returnTokenLength (AND_OP, 2); }
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 292 "cscanner.l"
{ return cscannerHelp_returnTokenLength (OR_OP, 2); }
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 293 "cscanner.l"
{ return cscannerHelp_returnTokenLength (TCAND, 2); }
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 294 "cscanner.l"
{ return cscannerHelp_returnTokenLength (LE_OP, 2); }
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 295 "cscanner.l"
{ return cscannerHelp_returnTokenLength (GE_OP, 2); }
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 296 "cscanner.l"
{ return cscannerHelp_returnTokenLength (EQ_OP, 2); }
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 297 "cscanner.l"
{ return cscannerHelp_returnTokenLength (NE_OP, 2); }
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 298 "cscanner.l"
{ return cscannerHelp_returnTokenLength (TSEMI, 1); }
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 299 "cscanner.l"
{ return cscannerHelp_returnTokenLength (TLBRACE, 1); }
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 300 "cscanner.l"
{ return cscannerHelp_returnTokenLength (TRBRACE, 1); }
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 301 "cscanner.l"
{ return cscannerHelp_returnTokenLength (TCOMMA, 1); }
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 302 "cscanner.l"
{ return cscannerHelp_returnTokenLength (TCOLON, 1); }
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 303 "cscanner.l"
{ return cscannerHelp_returnTokenLength (TASSIGN, 1); }
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 304 "cscanner.l"
{ return cscannerHelp_returnTokenLength (TLPAREN, 1); }
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 305 "cscanner.l"
{ return cscannerHelp_returnTokenLength (TRPAREN, 1); }
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 306 "cscanner.l"
{ return cscannerHelp_returnTokenLength (TLSQBR, 1); }
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 307 "cscanner.l"
{ return cscannerHelp_returnTokenLength (TRSQBR, 1); }
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 308 "cscanner.l"
{ return cscannerHelp_returnTokenLength (TDOT, 1); }
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 309 "cscanner.l"
{ return cscannerHelp_returnTokenLength (TAMPERSAND, 1); }
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 310 "cscanner.l"
{ return cscannerHelp_returnTokenLength (TEXCL, 1); }
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 311 "cscanner.l"
{ return cscannerHelp_returnTokenLength (TTILDE, 1); }
	YY_BREAK
case 157:
YY_RULE_SETUP
#line 312 "cscanner.l"
{ return cscannerHelp_returnTokenLength (TMINUS, 1); }
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 313 "cscanner.l"
{ return cscannerHelp_returnTokenLength (TPLUS, 1); }
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 314 "cscanner.l"
{ return cscannerHelp_returnTokenLength (TMULT, 1); }
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 315 "cscanner.l"
{ return cscannerHelp_returnTokenLength (TDIV, 1); }
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 316 "cscanner.l"
{ return cscannerHelp_returnTokenLength (TPERCENT, 1); }
	YY_BREAK
case 162:
YY_RULE_SETUP
#line 317 "cscanner.l"
{ return cscannerHelp_returnTokenLength (TLT, 1); }
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 318 "cscanner.l"
{ return cscannerHelp_returnTokenLength (TGT, 1); }
	YY_BREAK
case 164:
YY_RULE_SETUP
#line 319 "cscanner.l"
{ return cscannerHelp_returnTokenLength (TCIRC, 1); }
	YY_BREAK
case 165:
YY_RULE_SETUP
#line 320 "cscanner.l"
{ return cscannerHelp_returnTokenLength (TBAR, 1); }
	YY_BREAK
case 166:
YY_RULE_SETUP
#line 321 "cscanner.l"
{ return cscannerHelp_returnTokenLength (TQUEST, 1); }
	YY_BREAK
case 167:
YY_RULE_SETUP
#line 323 "cscanner.l"
{ incColumn (); }
	YY_BREAK
case 168:
/* rule 168 can match eol */
YY_RULE_SETUP
#line 324 "cscanner.l"
{ int tok = cscannerHelp_handleNewLine (); 
                  if (tok != BADTOK) return tok; }
	YY_BREAK
case 169:
YY_RULE_SETUP
#line 326 "cscanner.l"
{ cscannerHelp_setTokLength (6); 
		  
		  if (cscannerHelp_processMacro ()) {
		    if (context_inIterDef ()) 
		      { 
			return cscannerHelp_returnToken (LLMACROITER); 
		      }
		    if (context_inIterEnd ())
		      {
			return cscannerHelp_returnToken (LLMACROEND); 
		      }
		    if (context_inMacro ())
		      {
			return cscannerHelp_returnToken (LLMACRO); 
		      }
		  }
		}
	YY_BREAK
case 170:
YY_RULE_SETUP
#line 343 "cscanner.l"
{ if (context_inHeader () || context_inFunction ())
		    { 
		      cscannerHelp_handleMacro ();
		    }
                  else
		    {
		      int nspchar = cscannerHelp_ninput ();
		      int nspaces;

		      /* 
		      ** This is a hack to get the column number correct.
		      */

		      llassert (nspchar >= '0' && nspchar <= '9');
		      
		      nspaces = nspchar - '0';

		      cscannerHelp_setTokLength (5 + nspaces); 
		      
		      if (cscannerHelp_processMacro ()) 
			{
			  DPRINTF (("Here we are: %s", context_unparse ()));
			  
			  if (context_inIterDef ()) 
			    {
			      return cscannerHelp_returnToken (LLMACROITER); 
			    }
			  if (context_inIterEnd ())
			    {
			      return cscannerHelp_returnToken (LLMACROEND); 
			    }
			  if (context_inMacro ())
			    { 
			      return cscannerHelp_returnToken (LLMACRO); 
			    }
			}
		    }
		}
	YY_BREAK
case 171:
YY_RULE_SETUP
#line 381 "cscanner.l"
{ cscannerHelp_setTokLength (4); lldiagmsg (ctype_unparseTable ()); }
	YY_BREAK
case 172:
YY_RULE_SETUP
#line 382 "cscanner.l"
{ cscannerHelp_setTokLength (4); lldiagmsg (message ("Access types: %q", typeIdSet_unparse (context_fileAccessTypes ()))); }
	YY_BREAK
case 173:
YY_RULE_SETUP
#line 383 "cscanner.l"
{ cscannerHelp_setTokLength (3); 
		  lldiagmsg (message ("%q: *** marker ***", fileloc_unparse (g_currentloc)));
		}
	YY_BREAK
case 174:
YY_RULE_SETUP
#line 386 "cscanner.l"
{ cscannerHelp_setTokLength (3); usymtab_printLocal (); }
	YY_BREAK
case 175:
YY_RULE_SETUP
#line 387 "cscanner.l"
{ cscannerHelp_setTokLength (3); lldiagmsg (usymtab_unparseAliases ()); }
	YY_BREAK
case 176:
YY_RULE_SETUP
#line 388 "cscanner.l"
{ cscannerHelp_setTokLength (3); lldiagmsg (context_unparse ()); }
	YY_BREAK
case 177:
YY_RULE_SETUP
#line 389 "cscanner.l"
{ cscannerHelp_setTokLength (3); lldiagmsg (context_unparseClauses ()); }
	YY_BREAK
case 178:
YY_RULE_SETUP
#line 390 "cscanner.l"
{ cscannerHelp_setTokLength (3); usymtab_printGuards (); }
	YY_BREAK
case 179:
YY_RULE_SETUP
#line 391 "cscanner.l"
{ cscannerHelp_setTokLength (3); usymtab_printOut (); }
	YY_BREAK
case 180:
YY_RULE_SETUP
#line 392 "cscanner.l"
{ cscannerHelp_setTokLength (3); usymtab_printAll (); }
	YY_BREAK
case 181:
YY_RULE_SETUP
#line 393 "cscanner.l"
{ cscannerHelp_setTokLength (3); usymtab_printComplete (); }
	YY_BREAK
case 182:
YY_RULE_SETUP
#line 394 "cscanner.l"
{ cscannerHelp_setTokLength (3); usymtab_printTypes (); }
	YY_BREAK
case 183:
YY_RULE_SETUP
#line 395 "cscanner.l"
{ cscannerHelp_setTokLength (3); lldiagmsg (usymtab_unparseStack ()); }
	YY_BREAK
case 184:
YY_RULE_SETUP
#line 396 "cscanner.l"
{ cscannerHelp_setTokLength (3); return cscannerHelp_returnToken (QDREVEALSTATE); }
	YY_BREAK
case 185:
YY_RULE_SETUP
#line 397 "cscanner.l"
{ cscannerHelp_setTokLength (3); 
		  lldiagmsg (message ("Can modify: %q", 
				  sRefSet_unparse (context_modList ()))); 
		}
	YY_BREAK
case 186:
YY_RULE_SETUP
#line 401 "cscanner.l"
{ /* BEFORE_COMMENT_MARKER */
                  int tok; 
		  incColumn (); incColumn ();
		  tok = cscannerHelp_handleLlSpecial (); 

		  if (tok != BADTOK)
		    {
		      if (tok == CANNOTATION) {
			return (tok);
		      } else {
			/* Beware - this bashes yylval! */
			return cscannerHelp_returnToken (tok); 
		      }
		    }
		}
	YY_BREAK
case 187:
YY_RULE_SETUP
#line 416 "cscanner.l"
{ /* AFTER_COMMENT_MARKER */ 
		  cscannerHelp_exitSpecPart ();
		  return cscannerHelp_returnTokenLength (QENDMACRO, 2); }
	YY_BREAK
case 188:
YY_RULE_SETUP
#line 419 "cscanner.l"
{ incColumn (); cscannerHelp_setContinueLine (); }
	YY_BREAK
case 189:
YY_RULE_SETUP
#line 420 "cscanner.l"
{ incColumn (); 
                  if ((int) *yytext == 13 ) {
		     ;
                  } else {
		    voptgenerror
		      (FLG_SYNTAX, 
		       message ("Invalid character (ascii: %d), skipping character",
				(int)(*yytext)),
		       g_currentloc);
		  }
		}
	YY_BREAK
case 190:
YY_RULE_SETUP
#line 431 "cscanner.l"
ECHO;
	YY_BREAK
#line 2510 "cscanner.c"
case YY_STATE_EOF(INITIAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 576 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 576 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 575);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

    static void yyunput (int c, char * yy_bp )
{
	char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = (yy_n_chars) + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 431 "cscanner.l"


/*
** These need to go here, after flex-generated code defined input and unput.
*/

int cscanner_input (void)
{
  return input (); /* input is a static procedure defined by flex-generated code */
}

void cscanner_unput (int c)
{
  unput (c); /* unput is a static procedure defined by flex-generated code */
}


